@@ -27,8 +27,10 @@ class Gitlab(object):
             self.host = host[:-1]
         else:
             self.host = host
-        if self.host[:7] != 'http://':
-            self.host = 'http://' + self.host
+        if self.host[:7] == 'http://' or self.host[:8] == 'https://':
+            pass
+        else:
+            self.host = 'https://' + self.host
 
         self.api_url = self.host + "/api/v3"
         self.projects_url = self.api_url + "/projects"
@@ -991,8 +993,6 @@ class Gitlab(object):
         request = requests.post(self.groups_url,
                                 data={'name': name, 'path': path},
                                 headers=self.headers, verify=self.verify_ssl)
-        print request.status_code
-        print request.content
         if request.status_code == 201:
             return True
         else:
@@ -1362,16 +1362,19 @@ class Gitlab(object):
         else:
             return False
 
-    def listgroupmembers(self, group_id):
+    def listgroupmembers(self, group_id, page=1, per_page=20):
         """
         list group members
         new in 6.2
 
         lists the members of a given group id
         :param group_id: the group id
+        :param page: which page to return (default is 1)
+        :param per_page: number of items to return per page (default is 20)
         :return: the group's members
         """
-        request = requests.get(self.groups_url + "/" + str(group_id) + "/members",
+        data = {'page': page, 'per_page': per_page}
+        request = requests.get(self.groups_url + "/" + str(group_id) + "/members", params=data,
                                headers=self.headers, verify=self.verify_ssl)
         if request.status_code == 200:
             return json.loads(request.content.decode("utf-8"))
@@ -1658,4 +1661,4 @@ class Gitlab(object):
         if request.status_code == 200:
             return True
         else:
-            return False
\ No newline at end of file
+            return False
